.. include:: ../../README.md

Contents:
=========

.. toctree::
   :maxdepth: 2

   usage
   contributing


Feedback
========


If you encounter any errors or problems with **cmweather**,
please open an issue at the GitHub http://github.com/openradar/cmweather main repository.
